-- Update from 0.72 to 0.72.1
ALTER TABLE `glpi_groups` ADD INDEX `ldap_group_dn` ( `ldap_group_dn` );
ALTER TABLE `glpi_groups` ADD INDEX `ldap_value`  ( `ldap_value` );
ALTER TABLE `glpi_tracking` ADD INDEX `date_mod` (`date_mod`);
