-- Update from 0.72.1 to 0.72.2

-- Delete state from reservation search
DELETE FROM `glpi_display` WHERE type=29 AND num=31;

-- Clean licences alerts
DELETE FROM `glpi_alerts` WHERE device_type=20;

-- Correct search.constant numbers
UPDATE `glpi_display` SET num=34 WHERE num=3 AND type=11;
UPDATE `glpi_display` SET num=3 WHERE num=6 AND type=11;
UPDATE `glpi_display` SET num=34 WHERE num=3 AND type=17;
UPDATE `glpi_display` SET num=3 WHERE num=6 AND type=17;
UPDATE `glpi_display` SET num=34 WHERE num=3 AND type=15;
UPDATE `glpi_display` SET num=3 WHERE num=7 AND type=15;
UPDATE `glpi_display` SET num=46 WHERE num=40 AND type=1;
UPDATE `glpi_display` SET num=40 WHERE num=5 AND type=1;
UPDATE `glpi_display` SET num=5 WHERE num=8 AND type=1;
UPDATE `glpi_display` SET num=45 WHERE num=6 AND type=1;
UPDATE `glpi_display` SET num=6 WHERE num=9 AND type=1;
UPDATE `glpi_display` SET num=6 WHERE num=9 AND type=22;
UPDATE `glpi_display` SET num=5 WHERE num=8 AND type=22;
UPDATE `glpi_display` SET num=23 WHERE num=5 AND type=17;
UPDATE `glpi_display` SET num=23 WHERE num=5 AND type=11;
UPDATE `glpi_display` SET num=24 WHERE num=7 AND type=17;
UPDATE `glpi_display` SET num=24 WHERE num=7 AND type=11;
UPDATE `glpi_display` SET num=19 WHERE num=9 AND type=2;
UPDATE `glpi_display` SET num=19 WHERE num=9 AND type=3;
UPDATE `glpi_display` SET num=19 WHERE num=9 AND type=4;
UPDATE `glpi_display` SET num=19 WHERE num=9 AND type=5;
UPDATE `glpi_display` SET num=19 WHERE num=9 AND type=6;
UPDATE `glpi_display` SET num=19 WHERE num=9 AND type=23;
UPDATE `glpi_display` SET num=16 WHERE num=10 AND type=2;
UPDATE `glpi_display` SET num=16 WHERE num=10 AND type=3;
UPDATE `glpi_display` SET num=16 WHERE num=10 AND type=4;
UPDATE `glpi_display` SET num=16 WHERE num=10 AND type=5;
UPDATE `glpi_display` SET num=16 WHERE num=6 AND type=6;
UPDATE `glpi_display` SET num=16 WHERE num=7 AND type=7;
UPDATE `glpi_display` SET num=16 WHERE num=7 AND type=8;
UPDATE `glpi_display` SET num=16 WHERE num=10 AND type=11;
UPDATE `glpi_display` SET num=16 WHERE num=6 AND type=13;
UPDATE `glpi_display` SET num=16 WHERE num=12 AND type=15;
UPDATE `glpi_display` SET num=16 WHERE num=10 AND type=23;


